handler

package
v0.0.0-...-1598f0c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 1, 2020 License: GPL-3.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FillDestinationDirectories

func FillDestinationDirectories(b *domain.Bundle) error

FillDestinationDirectories finds the directories in the destination that match the sources

func FilterDownloadedContents

func FilterDownloadedContents(b *domain.Bundle) error

FilterDownloadedContents filters the array and leaves only the contents to download

func GetContentsFromHost

func GetContentsFromHost(conn *ssh.Client, dir string) ([]domain.Content, error)

GetContentsFromHost parses LS output to produce a curated list of contents

func ProcessItems

func ProcessItems(b *domain.Bundle) error

ProcessItems will extract what's to be extracted and copy what's to be copied

func RefreshLibrary

func RefreshLibrary(host string) error

RefreshLibrary refreshes the player library

Types

This section is empty.

Jump to