Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FillDestinationDirectories ¶
FillDestinationDirectories finds the directories in the destination that match the sources
func FilterDownloadedContents ¶
FilterDownloadedContents filters the array and leaves only the contents to download
func GetContentsFromHost ¶
GetContentsFromHost parses LS output to produce a curated list of contents
func ProcessItems ¶
ProcessItems will extract what's to be extracted and copy what's to be copied
func RefreshLibrary ¶
RefreshLibrary refreshes the player library
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.